@@ -28,20 +28,20 @@ from matplotlib_venn import venn2_unweighted, venn3_unweighted
 from sequana.rnadiff import RNADiffTable
 
 import colorlog
-logger = colorlog.getLogger(__name__)
 
+logger = colorlog.getLogger(__name__)
 
 
 __all__ = ["RNADiffCompare"]
 
 
-
-class Compare():
+class Compare:
     def __init__(self):
         pass
 
+
 class RNADiffCompare(Compare):
-    """ An object representation of results coming from a RNADiff analysis.
+    """An object representation of results coming from a RNADiff analysis.
 
     ::
 
@@ -67,19 +67,17 @@ class RNADiffCompare(Compare):
         else:
             raise NotImplementedError
 
-    def plot_venn_down(self, labels=None, ax=None,
-            title="Down expressed genes", mode="all"):
+    def plot_venn_down(self, labels=None, ax=None, title="Down expressed genes", mode="all"):
 
         kargs = {}
-        kargs['title'] = title
-        kargs['labels'] = labels
-        kargs['ax'] = ax
-        kargs['data1'] = set(self.r1.gene_lists['down'])
-        kargs['data2'] = set(self.r2.gene_lists['down'])
+        kargs["title"] = title
+        kargs["labels"] = labels
+        kargs["ax"] = ax
+        kargs["data1"] = set(self.r1.gene_lists["down"])
+        kargs["data2"] = set(self.r2.gene_lists["down"])
         self._venn(**kargs)
 
-    def plot_venn_up(self, labels=None,ax=None,
-         title="Up expressed genes", mode="all"):
+    def plot_venn_up(self, labels=None, ax=None, title="Up expressed genes", mode="all"):
         """Venn diagram of cond1 from RNADiff result1 vs cond2 in RNADiff
         result 2
 
@@ -96,74 +94,72 @@ class RNADiffCompare(Compare):
             c.plot_venn_up()
         """
         kargs = {}
-        kargs['title'] = title
-        kargs['labels'] = labels
-        kargs['ax'] = ax
-        kargs['data1'] = set(self.r1.gene_lists['up'])
-        kargs['data2'] = set(self.r2.gene_lists['up'])
+        kargs["title"] = title
+        kargs["labels"] = labels
+        kargs["ax"] = ax
+        kargs["data1"] = set(self.r1.gene_lists["up"])
+        kargs["data2"] = set(self.r2.gene_lists["up"])
         self._venn(**kargs)
 
-    def _venn(self, data1, data2, labels=None,
-        ax=None, title="expressed genes"):
+    def _venn(self, data1, data2, labels=None, ax=None, title="expressed genes"):
 
         from sequana.viz.venn import plot_venn
+
         if labels is None:
             labels = ["A", "B"]
 
-        plot_venn([data1, data2],
-            labels=labels, ax=ax, title=title)
+        plot_venn([data1, data2], labels=labels, ax=ax, title=title)
 
-    def plot_venn_all(self,  labels=None, ax=None,
-        title="all expressed genes", mode="all"):
+    def plot_venn_all(self, labels=None, ax=None, title="all expressed genes", mode="all"):
 
         kargs = {}
-        kargs['title'] = title
-        kargs['labels'] = labels
-        kargs['ax'] = ax
-        kargs['data1'] = set(self.r1.gene_lists['all'])
-        kargs['data2'] = set(self.r2.gene_lists['all'])
+        kargs["title"] = title
+        kargs["labels"] = labels
+        kargs["ax"] = ax
+        kargs["data1"] = set(self.r1.gene_lists["all"])
+        kargs["data2"] = set(self.r2.gene_lists["all"])
         self._venn(**kargs)
 
-
-    def plot_corrplot_counts_raw(self, samples=None, log2=True, lower='pie', upper='text'):
+    def plot_corrplot_counts_raw(self, samples=None, log2=True, lower="pie", upper="text"):
         from sequana.viz import corrplot
+
         if samples is None:
             samples = self.r1.counts_raw.columns
         df1 = self.r1.counts_raw[samples]
         df2 = self.r2.counts_raw[samples]
-        df = pd.concat([df1, df2], keys=['r1', 'r2'], axis=1)
+        df = pd.concat([df1, df2], keys=["r1", "r2"], axis=1)
         if log2:
             df = pylab.log2(df)
-        c = corrplot.Corrplot(df).plot(upper=upper,  lower=lower)
+        c = corrplot.Corrplot(df).plot(upper=upper, lower=lower)
         return df.corr()
 
-    def plot_corrplot_counts_normed(self, samples=None, log2=True, lower='pie', upper='text'):
+    def plot_corrplot_counts_normed(self, samples=None, log2=True, lower="pie", upper="text"):
         from sequana.viz import corrplot
+
         if samples is None:
             samples = self.r1.counts_raw.columns
         df1 = self.r1.counts_norm[samples]
         df2 = self.r2.counts_norm[samples]
-        df = pd.concat([df1, df2], keys=['r1', 'r2'], axis=1)
+        df = pd.concat([df1, df2], keys=["r1", "r2"], axis=1)
         if log2:
             df = pylab.log2(df)
-        c = corrplot.Corrplot(df).plot(upper=upper,  lower=lower)
+        c = corrplot.Corrplot(df).plot(upper=upper, lower=lower)
         return df.corr()
 
-    def plot_jaccard_distance(self, mode, padjs=[0.0001,0.001,0.01,0.05,0.1],
-            Nfc=50, smooth=False, window=5):
-        assert mode in ['down', 'up', 'all']
+    def plot_jaccard_distance(self, mode, padjs=[0.0001, 0.001, 0.01, 0.05, 0.1], Nfc=50, smooth=False, window=5):
+        assert mode in ["down", "up", "all"]
         pylab.clf()
 
         if mode == "down":
             m1 = self.r1.df.log2FoldChange.min()
             m2 = self.r2.df.log2FoldChange.min()
-            minimum = min(m1,m2)
+            minimum = min(m1, m2)
             print(m1, m2)
             X = pylab.linspace(0, minimum, Nfc)
         elif mode == "up":
             m1 = self.r1.df.log2FoldChange.max()
             m2 = self.r2.df.log2FoldChange.max()
-            maximum = max(m1,m2)
+            maximum = max(m1, m2)
             X = pylab.linspace(0, maximum, Nfc)
         else:
             minmax1 = self.r1.df.log2FoldChange.abs().max()
@@ -191,8 +187,8 @@ class RNADiffCompare(Compare):
                     # no overlap yet
                     I.append(100)
                 else:
-                    res = len(A.intersection(B)) / (len(A) + len(B) - len(A.intersection(B)))  * 100
-                    I.append(res)   
+                    res = len(A.intersection(B)) / (len(A) + len(B) - len(A.intersection(B))) * 100
+                    I.append(res)
                 common[padj].append(len(A.intersection(B)))
 
             try:
@@ -202,25 +198,33 @@ class RNADiffCompare(Compare):
                     assert False
             except:
                 pass
-            pylab.plot(X, I, 'o-', label=str(padj))
+            pylab.plot(X, I, "o-", label=str(padj))
         ax = pylab.gca()
         ax.set_ylabel("Jaccard similarity (intersection/union)")
         ax.set_xlabel("Fold change (log2)")
         ax2 = ax.twinx()
         for padj in padjs:
-            ax2.plot(X, common[padj], color='orange', ls='--')
+            ax2.plot(X, common[padj], color="orange", ls="--")
         ax2.set_ylabel("Cardinality of the union ")
         ax.legend()
-        ax.set_ylim([0,100])
-        #ax2.set_ylim([0,100])
+        ax.set_ylim([0, 100])
+        # ax2.set_ylim([0,100])
         if mode == "down":
-            ax.axvline(-2, ls='--', color='r')
+            ax.axvline(-2, ls="--", color="r")
         else:
-            ax.axvline(2, ls='--', color='r')
+            ax.axvline(2, ls="--", color="r")
 
-    def plot_common_major_counts(self, mode, labels=None,
-            switch_up_down_cond2=False, add_venn=True, xmax=None, 
-            title="", fontsize=12, sortby="log2FoldChange"):
+    def plot_common_major_counts(
+        self,
+        mode,
+        labels=None,
+        switch_up_down_cond2=False,
+        add_venn=True,
+        xmax=None,
+        title="",
+        fontsize=12,
+        sortby="log2FoldChange",
+    ):
         """
 
         :param mode: down, up or all
@@ -238,49 +242,49 @@ class RNADiffCompare(Compare):
             )
             c.plot_common_major_counts("down")
         """
-        #cond1, cond2 = self._get_cond1_cond2()
+        # cond1, cond2 = self._get_cond1_cond2()
         if labels is None:
-            labels = ['r1', 'r2']
+            labels = ["r1", "r2"]
 
         if mode in ["down"]:
             # Negative values !
-            gl1 = set(self.r1.gene_lists['down'])
-            gl2 =  set(self.r2.gene_lists['down'])
+            gl1 = set(self.r1.gene_lists["down"])
+            gl2 = set(self.r2.gene_lists["down"])
             A = self.r1.df.loc[gl1].sort_values(by=sortby)
             B = self.r2.df.loc[gl1].sort_values(by=sortby)
         else:
             gl1 = set(self.r1.gene_lists[mode])
-            gl2 =  set(self.r2.gene_lists[mode])
+            gl2 = set(self.r2.gene_lists[mode])
             A = self.r1.df.loc[gl1].sort_values(by=sortby, ascending=False)
             B = self.r2.df.loc[gl1].sort_values(by=sortby, ascending=False)
         # sometimes, up and down may be inverted as compared to the other
         # conditions
 
         N = []
-        for i in range(1,max(len(A), len(B))):
+        for i in range(1, max(len(A), len(B))):
             a = A.iloc[0:i].index
             b = B.iloc[0:i].index
             n = len(set(b).intersection(set(a)))
-            N.append(n / i*100)
+            N.append(n / i * 100)
 
         max_common = len(set(A.index).intersection(set(B.index)))
         pylab.clf()
         if len(A) > len(B):
-            pylab.axhline(max_common/len(A)*100, color="r", ls='--', label="min set intersection")
+            pylab.axhline(max_common / len(A) * 100, color="r", ls="--", label="min set intersection")
             pylab.axvline(len(B), ls="--", color="k", label="rank of minor set")
         else:
-            pylab.axhline(max_common/len(B)*100, color='r', ls='--', label="min set intersect")
+            pylab.axhline(max_common / len(B) * 100, color="r", ls="--", label="min set intersect")
             pylab.axvline(len(A), ls="--", color="k", label="rank of minor set")
 
         pylab.plot(N)
-        pylab.xlabel('rank', fontsize=fontsize)
-        pylab.ylabel('% common features', fontsize=fontsize)
+        pylab.xlabel("rank", fontsize=fontsize)
+        pylab.ylabel("% common features", fontsize=fontsize)
         pylab.grid(True)
-        pylab.ylim([0,100])
+        pylab.ylim([0, 100])
         if xmax:
             pylab.xlim([0, xmax])
         else:
-            pylab.xlim([0, max(len(A),len(B))])
+            pylab.xlim([0, max(len(A), len(B))])
         pylab.title(title, fontsize=fontsize)
         ax = pylab.gca()
         ax2 = ax.twinx()
@@ -291,16 +295,13 @@ class RNADiffCompare(Compare):
 
         if add_venn:
             f = pylab.gcf()
-            ax = f.add_axes([0.5,0.5,0.35,0.35], facecolor="grey")
-            if mode=="down":
-                self.plot_venn_down(ax=ax, title=None, labels=labels,
-                    mode="two_only")
-            elif mode=="up":
-                self.plot_venn_up(ax=ax, title=None, labels=labels,
-                    mode="two_only")
-            elif mode=="all":
-                self.plot_venn_all(ax=ax, title=None, labels=labels,
-                    mode="two_only")
+            ax = f.add_axes([0.5, 0.5, 0.35, 0.35], facecolor="grey")
+            if mode == "down":
+                self.plot_venn_down(ax=ax, title=None, labels=labels, mode="two_only")
+            elif mode == "up":
+                self.plot_venn_up(ax=ax, title=None, labels=labels, mode="two_only")
+            elif mode == "all":
+                self.plot_venn_all(ax=ax, title=None, labels=labels, mode="two_only")
 
     def plot_foldchange(self):
         mode = "all"
@@ -319,13 +320,14 @@ class RNADiffCompare(Compare):
         Ac = A.loc[AB]
         Bc = B.loc[AB]
 
-
-        pylab.plot(self.r1.df.loc[common].log2FoldChange, 
-                   self.r2.df.loc[common].log2FoldChange, 'ko', alpha=0.5, markersize=1)
-        pylab.plot(Ac.log2FoldChange, Bc.log2FoldChange, 'or', alpha=0.5)
-        pylab.plot(Ao.log2FoldChange, self.r2.df.loc[Ao.index].log2FoldChange, '*b', alpha=0.5)
-        pylab.plot(Bo.log2FoldChange, self.r1.df.loc[Bo.index].log2FoldChange, 
-            color='cyan', marker="o", lw=0, alpha=0.5)
+        pylab.plot(
+            self.r1.df.loc[common].log2FoldChange, self.r2.df.loc[common].log2FoldChange, "ko", alpha=0.5, markersize=1
+        )
+        pylab.plot(Ac.log2FoldChange, Bc.log2FoldChange, "or", alpha=0.5)
+        pylab.plot(Ao.log2FoldChange, self.r2.df.loc[Ao.index].log2FoldChange, "*b", alpha=0.5)
+        pylab.plot(
+            Bo.log2FoldChange, self.r1.df.loc[Bo.index].log2FoldChange, color="cyan", marker="o", lw=0, alpha=0.5
+        )
 
     def plot_volcano_differences(self, mode="all"):
         cond1, cond2 = "cond1", "cond2"
@@ -339,40 +341,71 @@ class RNADiffCompare(Compare):
         Bcommon = B.loc[AB]
 
         pylab.clf()
-        pylab.plot(Acommon.log2FoldChange, -np.log10(Acommon.padj), marker="o",
-            alpha=0.5, color="r", lw=0, label="Common in experiment 1", pickradius=4,
-            picker=True)
-        pylab.plot(Bcommon.log2FoldChange, -np.log10(Bcommon.padj), marker="o",
-            alpha=0.5, color="orange", lw=0, label="Common in experiment 2", pickradius=4,
-            picker=True)
+        pylab.plot(
+            Acommon.log2FoldChange,
+            -np.log10(Acommon.padj),
+            marker="o",
+            alpha=0.5,
+            color="r",
+            lw=0,
+            label="Common in experiment 1",
+            pickradius=4,
+            picker=True,
+        )
+        pylab.plot(
+            Bcommon.log2FoldChange,
+            -np.log10(Bcommon.padj),
+            marker="o",
+            alpha=0.5,
+            color="orange",
+            lw=0,
+            label="Common in experiment 2",
+            pickradius=4,
+            picker=True,
+        )
 
         for x in AB:
             a_l = A.loc[x].log2FoldChange
             a_p = -np.log10(A.loc[x].padj)
             b_l = B.loc[x].log2FoldChange
             b_p = -np.log10(B.loc[x].padj)
-            pylab.plot([a_l, b_l], [a_p, b_p], 'k', alpha=0.5)
+            pylab.plot([a_l, b_l], [a_p, b_p], "k", alpha=0.5)
 
-        pylab.plot(Bonly.log2FoldChange, -np.log10(Bonly.padj), marker="*",
-            alpha=0.5, color="blue", lw=0, label="In experiment 2 only", pickradius=4,
-            picker=True)
-        pylab.plot(Aonly.log2FoldChange, -np.log10(Aonly.padj), marker="*",
-            alpha=0.5, color="cyan", lw=0, label="In experiment 1 only", pickradius=4,
-            picker=True)
+        pylab.plot(
+            Bonly.log2FoldChange,
+            -np.log10(Bonly.padj),
+            marker="*",
+            alpha=0.5,
+            color="blue",
+            lw=0,
+            label="In experiment 2 only",
+            pickradius=4,
+            picker=True,
+        )
+        pylab.plot(
+            Aonly.log2FoldChange,
+            -np.log10(Aonly.padj),
+            marker="*",
+            alpha=0.5,
+            color="cyan",
+            lw=0,
+            label="In experiment 1 only",
+            pickradius=4,
+            picker=True,
+        )
 
         for name, x in Bonly.iterrows():
             x1 = x.log2FoldChange
             y1 = -np.log10(x.padj)
             x2 = self.r1.df.loc[name].log2FoldChange
             y2 = -np.log10(self.r1.df.loc[name].padj)
-            pylab.plot( [x1,x2], [y1,y2], ls="--", color='r')
+            pylab.plot([x1, x2], [y1, y2], ls="--", color="r")
         for name, x in Aonly.iterrows():
             x1 = x.log2FoldChange
             y1 = -np.log10(x.padj)
             x2 = self.r2.df.loc[name].log2FoldChange
             y2 = -np.log10(self.r2.df.loc[name].padj)
-            pylab.plot( [x1,x2], [y1,y2], ls="-", color='r')
-
+            pylab.plot([x1, x2], [y1, y2], ls="-", color="r")
 
         pylab.axhline(1.33, alpha=0.5, ls="--", color="r")
 
@@ -410,12 +443,28 @@ class RNADiffCompare(Compare):
             cond2 += "(2)"
 
         pylab.clf()
-        pylab.plot(A.log2FoldChange, -np.log10(A.padj), marker="o",
-            alpha=0.5, color="r", lw=0, label=labels[0], pickradius=4,
-            picker=True)
-        pylab.plot(B.log2FoldChange, -np.log10(B.padj), marker="x",
-            alpha=0.5, color="k", lw=0, label=labels[1], pickradius=4,
-            picker=True)
+        pylab.plot(
+            A.log2FoldChange,
+            -np.log10(A.padj),
+            marker="o",
+            alpha=0.5,
+            color="r",
+            lw=0,
+            label=labels[0],
+            pickradius=4,
+            picker=True,
+        )
+        pylab.plot(
+            B.log2FoldChange,
+            -np.log10(B.padj),
+            marker="x",
+            alpha=0.5,
+            color="k",
+            lw=0,
+            label=labels[1],
+            pickradius=4,
+            picker=True,
+        )
 
         genes = list(A.index) + list(B.index)
         pylab.grid(True)
@@ -430,36 +479,32 @@ class RNADiffCompare(Compare):
             label = thisline.get_label()
             if label == cond1:
                 gene_name = A.index[event.ind[0]]
-                x1 = round(A.loc[gene_name].log2FoldChange,1)
-                y1 = round(-np.log10(A.loc[gene_name].padj),1)
+                x1 = round(A.loc[gene_name].log2FoldChange, 1)
+                y1 = round(-np.log10(A.loc[gene_name].padj), 1)
                 try:
-                    x2 = round(B.loc[gene_name].log2FoldChange,1)
-                    y2 = round(-np.log10(B.loc[gene_name].padj),1)
+                    x2 = round(B.loc[gene_name].log2FoldChange, 1)
+                    y2 = round(-np.log10(B.loc[gene_name].padj), 1)
                 except:
                     x2, y2 = None, None
             else:
                 gene_name = B.index[event.ind[0]]
-                x1 = round(B.loc[gene_name].log2FoldChange,1)
-                y1 = round(-np.log10(B.loc[gene_name].padj),1)
+                x1 = round(B.loc[gene_name].log2FoldChange, 1)
+                y1 = round(-np.log10(B.loc[gene_name].padj), 1)
                 try:
-                    x2 = round(A.loc[gene_name].log2FoldChange,1)
-                    y2 = round(-np.log10(A.loc[gene_name].padj),1)
+                    x2 = round(A.loc[gene_name].log2FoldChange, 1)
+                    y2 = round(-np.log10(A.loc[gene_name].padj), 1)
                 except:
                     x2, y2 = None, None
 
             try:
                 if x2 is None:
-                    ax.title.set_text("{} at pos [{},{}]".format(
-                        gene_name,x1,y1))
+                    ax.title.set_text("{} at pos [{},{}]".format(gene_name, x1, y1))
                 else:
-                    ax.title.set_text("{} at pos [{},{}] and [{},{}]".format(
-                            gene_name,x1,y1,x2,y2))
+                    ax.title.set_text("{} at pos [{},{}] and [{},{}]".format(gene_name, x1, y1, x2, y2))
             except:
                 print("exception")
                 ax.title.set_text("")
             pylab.draw()
+
         fig = pylab.gcf()
-        fig.canvas.mpl_connect('pick_event', onpick)
-
-
-
+        fig.canvas.mpl_connect("pick_event", onpick)
