@@ -17,16 +17,18 @@
 """Simple VST transformation"""
 from sequana.lazy import numpy as np
 import colorlog
+
 logger = colorlog.getLogger(__name__)
 
 
-__all__ = ['VST']
+__all__ = ["VST"]
 
-class VST():
+
+class VST:
     """
 
     ::
-    
+
         v = VST()
         v.anscombe(X)
 
@@ -35,6 +37,7 @@ class VST():
         IEEE Trans. Image Process., doi:10.1109/TIP.2012.2202675
 
     """
+
     def __init__(self):
         pass
 
@@ -55,13 +58,13 @@ class VST():
         mean :math:`\sqrt{x+3/8} - 1/(4m^{1/2})`
         """
 
-        #if np.mean(x) <4:
+        # if np.mean(x) <4:
         #    logger.warning("Mean of input data below 4")
         try:
             # If a dataframe, we do not want to change it
-            return 2.0 * np.sqrt(x + 3.0/8.0)
+            return 2.0 * np.sqrt(x + 3.0 / 8.0)
         except:
-            return 2.0 * np.sqrt(np.array(x) + 3.0/8.0)
+            return 2.0 * np.sqrt(np.array(x) + 3.0 / 8.0)
 
     @staticmethod
     def inverse_anscombe(x):
@@ -73,11 +76,14 @@ class VST():
         variance-stabilizing transformation. Image Processing.
         """
         # should be positive
-        # should wotk for dataframe and numpy arrays 
-        return (1.0/4.0 * np.power(x, 2) +
-                1.0/4.0 * np.sqrt(3.0/2.0) * np.power(x, -1.0) -
-                11.0/8.0 * np.power(x, -2.0) + 
-                5.0/8.0 * np.sqrt(3.0/2.0) * np.power(x, -3.0) - 1.0 / 8.0)
+        # should wotk for dataframe and numpy arrays
+        return (
+            1.0 / 4.0 * np.power(x, 2)
+            + 1.0 / 4.0 * np.sqrt(3.0 / 2.0) * np.power(x, -1.0)
+            - 11.0 / 8.0 * np.power(x, -2.0)
+            + 5.0 / 8.0 * np.sqrt(3.0 / 2.0) * np.power(x, -3.0)
+            - 1.0 / 8.0
+        )
 
     @staticmethod
     def generalized_anscombe(x, mu, sigma, gain=1.0):
@@ -87,19 +93,18 @@ class VST():
 
         The input signal  z  is assumed to follow the Poisson-Gaussian noise
         model::
-    
+
             x = gain * p + n
 
         where gain is the camera gain and mu and sigma are the read noise
-        mean and standard deviation. X should contain only positive values.  
+        mean and standard deviation. X should contain only positive values.
         Negative values are ignored. Biased for low counts
         """
         try:
             # If a dataframe, we do not want to change it
-            y = gain*x + (gain**2) * 3.0/8.0 + sigma**2 - gain*mu
+            y = gain * x + (gain ** 2) * 3.0 / 8.0 + sigma ** 2 - gain * mu
             return (2.0 / gain) * np.sqrt(np.maximum(y, 0.0))
         except:
             x = np.array(x)
-            y = gain*x + (gain**2) * 3.0/8.0 + sigma**2 - gain*mu
+            y = gain * x + (gain ** 2) * 3.0 / 8.0 + sigma ** 2 - gain * mu
             return (2.0 / gain) * np.sqrt(np.maximum(y, 0.0))
-
